ImageProcess class

compressing cropping process for web is done here

Constructors

ImageProcess(Uint8List imageBytes, {required int encodingQuality, String? workerPath, required OutputImageFormat outputImageFormat})

Properties

encodingQuality → int
JPEG encoding quality, not used yet
final
hashCode → int
The hash code for this object.
no setterinherited
imageBytes ↔ Uint8List
image bytes which will be of user's picked image.
getter/setter pair
outputImageFormat → OutputImageFormat
Output format of image
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
worker ↔ Worker
web worker to do multithreaded computation.
latefinal

Methods

compress(dynamic onBytesLoaded(), dynamic onLibraryImageLoaded(Image)) → void
compressed image is shown for user's reference
crop(int imageCropX, int imageCropY, int imageCropWidth, int imageCropHeight, dynamic onImageLoaded(Image, Uint8List)) → void
Image cropping will be done by crop method
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited